package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````V!8``#0```!HE`````0`!30`(``'
M`"@`&P`:``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!<````7````!`````$````!````````````````````F(X`
M`)B.```%```````!``$```"8C@``F(X!`)B.`0"X`@``+`,```8```````$`
M`@```*2.``"DC@$`I(X!`/````#P````!@````0````$````+`$``"P!```L
M`0``3````$P````$````!````%#E=&2<AP``G(<``)R'```,`0``#`$```0`
M```$````+W5S<B]L:6)E>&5C+VQD+F5L9E]S;P``!P````0````!````3F5T
M0E-$``#`K](U!`````0````#````4&%8```````'````"0````4```!.971"
M4T0``&5A<FUV-FAF`````&$```!L```````````````Q````#@``````````
M````.0````\```!!`````````#```````````P```$\```!D`````````"``
M``!.````!@```!X````5`````````$0```!9````8``````````8````/0``
M`%L```!E`````````&@```!J````+P```!,```!:````1@```!8```!?````
M2`````````!+````1P```#8```!>````)@```"H`````````!P```%``````
M````#````"P```!K````70```$T````A````40```&D`````````8@``````
M```9````+@```$(````````````````````2````,P`````````*````8P``
M`"L`````````"0`````````D````.@````````!2````!0```$D````<````
M/`````````````````````````!,`````````#L```!5````9@````````!G
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!0`````````
M`````````````````````````````````````",````B`````````"D`````
M````"P```"<````H````+0``````````````#0`````````=````&P```#4`
M```:```````````````1`````````#0````R````.````!\`````````````
M``````````````````0```````````````````!#````)0``````````````
M`````!<`````````0````$4````(````````````````````/P````````!4
M``````````````!8```````````````^````5P````````!3`````````$H`
M```0``````````````!6````7````#<```!A````````````````````````
M````````````V!8````````#``L``````*".`0```````P`1`)D`````````
M`````!(````,```````````````2````%```````````````$@```'H#```T
M(@``"````!(`"P`<```````````````B````*P``````````````$@```$,#
M`````````````!(````Q```````````````2````BP,``%"1`0``````$``5
M`#@``````````````!(```"9`P``U"D``"`````2``L`/P``````````````
M$@```%`#`````````````!(```!'```````````````2````M`,````T``!D
M````$@`+`(H``````````````!(```#(`P``Q)$!```````0`!4`3P``````
M````````$@```,`#``!0D0$``````!``%`!?```````````````2````;@``
M````````````$@```'0``````````````!(```![```````````````2````
MA0``````````````$@```(\``````````````!(```#'`P``Q)$!```````0
M`!4`F```````````````$@```%<"`````````````!(```">````````````
M```2````I0``````````````$@```+,``````````````!(```#$````````
M```````1````T0``````````````$@```-,#``"\)```,````!(`"P#@`P``
M["0``&`````2``L`[`,``.@J``"(!@``$@`+`-\``````````````!8```#R
M```````````````2````8@,`````````````$@```/T``````````````!(`
M```&`0``P)$!``0````1`!4`#@$`````````````$@```!<!````````````
M`!(````Y`P`````````````2````(P$`````````````$@```"H!````````
M`````!(```#Y`P``Q$```!@!```2``L`/0$`````````````$0```$\!````
M`````````!(```!?`0`````````````2````;0$`````````````$@```'(!
M`````````````!$```"!`0`````````````2````!`0``$R1`0`$````$0`4
M`)`!`````````````!(```"<`0`````````````2````L0$`````````````
M$@```+P!`````````````!(```!U`P``Q)$!```````0`!4`\P(`````````
M````$@```,\!`````````````!(```!'!```V!8````````2``L`W0$`````
M````````$@```.4!`````````````"(```#]`0`````````````2````"0(`
M````````````$@````X$``#$D0$``````!``%0`6!```3"4``,P!```2``L`
M#P(`````````````(@```"4"`````````````!(````P`@`````````````2
M````(P0``-Q!``!X`0``$@`+`$$"`````````````!(````M!```4)$!````
M```0`!4`.00``%0A``!H````$@`+`$$$```P1```E`(``!(`"P!(`@``````
M```````2````1@0``-@6````````$@`+`$\"`````````````!(```!.!```
M/"(``(`"```2``L`6P0``/0I``#T````$@`+`%8"`````````````!(```!M
M!```&"<``(`````2``L`7P(`````````````$@```'`"`````````````!(`
M```"`P`````````````2````=P(`````````````$@```'L$``"8)P``7```
M`!(`"P"&`@`````````````2````CP(`````````````$@```)4"````````
M`````!(````L`P`````````````2````F@(`````````````$@```!\#``"$
MD0$`!````!$`%0"B`@`````````````2````5P,`````````````$@```*D"
M`````````````!(```"#!```9$```&`````2``L`L`(`````````````$@``
M`+\"`````````````!$````4`P``")$!``0````1`!0`C`0``'`Q``"0`@``
M$@`+`#8!`````````````!(```#$`@`````````````2````:0,`````````
M````$@````!L:6)P97)L+G-O`')E86QL;V,`;65M;6]V90!?7V-X85]F:6YA
M;&EZ90!R;61I<@!S=')S='(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?;'-T
M870U,`!P97)L7V9R964`7U]S=&%T-3``7V5X:70`;65M8W!Y`'!E<FQ?9&5S
M=')U8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``4&5R;%]S=E]S
M971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E
M;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`&UE;7-E=`!097)L7W-A9F5S
M>7-M86QL;V,`7U]S=&%C:U]C:&M?9W5A<F0`4&5R;%]G=E]F971C:'!V`%]?
M<W!R:6YT9E]C:&L`<F5A9`!03%]M96UO<GE?=W)A<`!097)L7W-Y<U]I;FET
M,P!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3
M`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?97)R;F\`7U]D
M97)E9VES=&5R7V9R86UE7VEN9F\`4&5R;%]M9U]S970`;6MD:7(`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`'!E<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A
M8V-E<W,`9V5T<&ED`&UE;6-H<@!V9G!R:6YT9@!097)L7V%T9F]R:U]L;V-K
M`&UE;6-M<`!097)L7W-V7W-E='!V;@!P97)L7W)U;@!L<V5E:P!O<&5N`'-P
M<FEN=&8`9V5T=6ED`'-T<FQE;@!?7W1L<U]G971?861D<@!?7W-&`'-T<F-M
M<`!L:6)M+G-O+C``;&EB8W)Y<'0N<V\N,0!L:6)P=&AR96%D+G-O+C$`<'1H
M<F5A9%]A=&9O<FL`<W1R9'5P`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S
M7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!?7W-T<&-P>5]C:&L`
M871E>&ET`%]L:6)C7VEN:70`<W1R=&]K`%]?<F5A9&1I<C,P`%]E;F0`<&%R
M7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`
M;7E?<&%R7W!L`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S
M<U]S=&%R=`!X<U]I;FET`&UA:6X`7U]S=&%R=`!P87)?9FEN9'!R;V<`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H85]I;FET
M`%A37TEN=&5R;F%L<U]005)?0D]/5``O=7-R+W!K9R]L:6(O<&5R;#4O-2XS
M."XP+V5A<FUV-FAF+6YE=&)S9"UT:')E860M;75L=&DO0T]213HO=7-R+W!K
M9R]L:6(``)B.`0`7````G(X!`!<```"LD`$`%P```+20`0`7````O)`!`!<`
M``#,D`$`%P```-"0`0`7````V)`!`!<```#@D`$`%P```/"0`0`7````^)`!
M`!<`````D0$`%P````21`0`7````")$!`!<````,D0$`%P```!R1`0`7````
M()$!`!<````HD0$`%P```"R1`0`7````,)$!`!<````TD0$`%P```#B1`0`7
M````0)$!`!<```!$D0$`%P```$R1`0`7````L)`!`!4'``"XD`$`%10``,"0
M`0`5(@``Q)`!`!$G``#(D`$`$B<``-20`0`5,@``W)`!`!4V``#DD`$`%3P`
M`.B0`0`50@``[)`!`!5'``#TD`$`%58``/R0`0`59@``H(\!`!8#``"DCP$`
M%@0``*B/`0`6!0``K(\!`!8'``"PCP$`%@@``+2/`0`6"0``N(\!`!8*``"\
MCP$`%@P``,"/`0`6#@``Q(\!`!8/``#(CP$`%A```,R/`0`6$@``T(\!`!86
M``#4CP$`%A<``-B/`0`6&```W(\!`!89``#@CP$`%AH``.2/`0`6&P``Z(\!
M`!8=``#LCP$`%AX``/"/`0`6'P``](\!`!8@``#XCP$`%B$``/R/`0`6(P``
M`)`!`!8H```$D`$`%BD```B0`0`6*@``#)`!`!8L```0D`$`%BT``!20`0`6
M+@``&)`!`!8O```<D`$`%C```""0`0`6,P``))`!`!8T```HD`$`%C4``"R0
M`0`6-P``,)`!`!8Y```TD`$`%CH``#B0`0`6.P``/)`!`!8^``!`D`$`%C\`
M`$20`0`600``2)`!`!9"``!,D`$`%D,``%"0`0`61```5)`!`!9'``!8D`$`
M%D@``%R0`0`620``8)`!`!9+``!DD`$`%D\``&B0`0`640``;)`!`!94``!P
MD`$`%E<``'20`0`66```>)`!`!99``!\D`$`%EL``("0`0`67```A)`!`!9=
M``"(D`$`%EX``(R0`0`67P``D)`!`!9A``"4D`$`%F(``)B0`0`68P``G)`!
M`!9E``"@D`$`%FD``*20`0`6:@``J)`!`!9K```$X"WE!."?Y0[@C^`(\+[E
MY'L!``#&C^(7RHSBY/N\Y0#&C^(7RHSBW/N\Y0#&C^(7RHSBU/N\Y0#&C^(7
MRHSBS/N\Y0#&C^(7RHSBQ/N\Y0#&C^(7RHSBO/N\Y0#&C^(7RHSBM/N\Y0#&
MC^(7RHSBK/N\Y0#&C^(7RHSBI/N\Y0#&C^(7RHSBG/N\Y0#&C^(7RHSBE/N\
MY0#&C^(7RHSBC/N\Y0#&C^(7RHSBA/N\Y0#&C^(7RHSB?/N\Y0#&C^(7RHSB
M=/N\Y0#&C^(7RHSB;/N\Y0#&C^(7RHSB9/N\Y0#&C^(7RHSB7/N\Y0#&C^(7
MRHSB5/N\Y0#&C^(7RHSB3/N\Y0#&C^(7RHSB1/N\Y0#&C^(7RHSB//N\Y0#&
MC^(7RHSB-/N\Y0#&C^(7RHSB+/N\Y0#&C^(7RHSB)/N\Y0#&C^(7RHSB'/N\
MY0#&C^(7RHSB%/N\Y0#&C^(7RHSB#/N\Y0#&C^(7RHSB!/N\Y0#&C^(7RHSB
M_/J\Y0#&C^(7RHSB]/J\Y0#&C^(7RHSB[/J\Y0#&C^(7RHSBY/J\Y0#&C^(7
MRHSBW/J\Y0#&C^(7RHSBU/J\Y0#&C^(7RHSBS/J\Y0#&C^(7RHSBQ/J\Y0#&
MC^(7RHSBO/J\Y0#&C^(7RHSBM/J\Y0#&C^(7RHSBK/J\Y0#&C^(7RHSBI/J\
MY0#&C^(7RHSBG/J\Y0#&C^(7RHSBE/J\Y0#&C^(7RHSBC/J\Y0#&C^(7RHSB
MA/J\Y0#&C^(7RHSB?/J\Y0#&C^(7RHSB=/J\Y0#&C^(7RHSB;/J\Y0#&C^(7
MRHSB9/J\Y0#&C^(7RHSB7/J\Y0#&C^(7RHSB5/J\Y0#&C^(7RHSB3/J\Y0#&
MC^(7RHSB1/J\Y0#&C^(7RHSB//J\Y0#&C^(7RHSB-/J\Y0#&C^(7RHSB+/J\
MY0#&C^(7RHSB)/J\Y0#&C^(7RHSB'/J\Y0#&C^(7RHSB%/J\Y0#&C^(7RHSB
M#/J\Y0#&C^(7RHSB!/J\Y0#&C^(7RHSB_/F\Y0#&C^(7RHSB]/F\Y0#&C^(7
MRHSB[/F\Y0#&C^(7RHSBY/F\Y0#&C^(7RHSBW/F\Y0#&C^(7RHSBU/F\Y0`0
MH.$"`*#A!]#-XSD``.H-P*#A,-@MZ40@G^5$,)_E`B"/X$!`G^4#,)+G!$"/
MX`,`5.$$L$SB,*B=*`-0@^($,(3B`U!%X`-0Q>,#4(7@!#"4Y#/_+^$%`%3A
M^___&C"HG>B4>`$`&`$``)!W`0`-P*#A\-@MZ6P@G^5L$)_E;#"?Y0(@C^`!
M0)+G`S"2YP2P3.(#`%3A\*B=*`0@U.6@`%+C#P``&@A`A.('<(/B!'!'X`=P
MQ^,$<(?@"%`4Y01@H.$`,)7E,_\OX0<`5.$``(7E\*B="`0PUN4(0(3BH`!3
MX_3__PHB___K,'@!`#P!```@`0``#<"@X8#8+>EP@9_E!+!,X@S03>(`8%'B
M"("/X$L```I<,9_E`""6Y0,0F.=4,9_E`,"2Y0!@@>4#<)CG"#"6Y0``7.,`
M,(?E.@``"C@QG^4#$)CG`,"!Y0`@DN4`,-+E``!3XP4```H!((+B+P!3XP`@
M@04!,-+D``!3X_K__QH``%#C````"O#^_^N+___K^#"?Y0,PF.<``%/C-0``
M"NPPG^7L0)_E`S"8YP1`C^`#`%3A"```*@-0@^($,(3B`U!%X`-0Q>,#4(7@
M!#"4Y#/_+^$%`%3A^___&K@`G^6X0)_E``"/X-C^_^NP,)_E!$"/X`,PF.<#
M`%3A"```*@-0@^($,(3B`U!%X`-0Q>,#4(7@!#"4Y#/_+^$$`%7A^___&@`@
ME^4`$);E!`"6Y<H*`.NJ_O_K3""?Y60PG^4"()CG`S"/X``P@N7+___J$R"@
MXU`PG^4`((WE`S"/X`(@H.,$`*#C`!"@X_/^_^L!`*#CT/[_ZW[__^O'___J
MI'<!`&0!```X`0``;`$``%P!```H`0``%'8!`"S^___0=0$`1`$``&1X`0"0
M+0``#<"@X=0PG^7PVRWI`(!0X@2P3.(!<*#A`S"/X"L```J\()_E`C"3YP"0
MD^4``%GC*```"@`PV.4]4%/B`5"@$P``4^,`4*`#``!5XQ$``!H`0)GE``!4
MXPP```H)8*#A!2"@X0@0H.$$`*#AB/[_ZP``4.,"```:!3#4YST`4^,+```*
M!$"VY0``5./S__\:!`"@X?"KG>@(4*#A`3#UY0``4^,]`%,3^___&@A01>#F
M___J"6!&X`%0A>)&8:#A!4"$X`!@A^4$`*#A\*N=Z`A`H.'M___J"4"@X>O_
M_^KT=0$`.`$```W`H.'PV"WI!+!,X@C03>(`4*#A@'"?Y8`PG^4'<(_@`V"7
MYR1`2^(`,);E(#`+Y000H.$%`*#AMO__ZP``4.,.```*6#"?Y200&^4#,)?G
M`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK
M___J("`;Y0`PEN4#`%+A`0``&AS02^+PJ)WH;?[_ZPAU`0!``0``.`$```W`
MH.'PWRWI!+!,XJS03>(T,9_E-"&?Y0,PC^`"0)/G`&!0X@`PE.4P,`OE`@``
M"@`PUN4``%/C!0``&C`@&^4`,)3E`P!2X3X``!HHT$OB\*^=Z&;^_^L`<%#B
M]O__"NPPG^7L@)_E`S"/X.B0G^70,`OES#!+X@B`C^`)D(_@U#`+Y0<`H.'+
M_O_K``!0XR4```H-4(#B!0"@X0@0H.'"_O_K``!0X_7__PH)$*#A!0"@X;W^
M_^L``%#C\/__"@8`H.&P_O_K`*"@X04`H.&M_O_K``"*X`(`@.*P_O_K`*"@
MX04PH.$&(*#AT!`;Y9S^_^O4$!OE"@"@X1O^_^L!`'#C"@"@X0,```K$,!OE
M#SH#X@$)4^,(```*"O[_ZPH`H.'__?_KU?__Z@<`H.$I_O_K!@"@X>7]_^N^
M___JKO__Z_7__^H7_O_K9'0!`$`!``!T*P``7"L``%PK```-P*#A\-\MZ02P
M3.(4T$WB`4"@X0R2G^4,,I_E`"#1Y0F0C^`#8)GG/0!2XP%`@0(`,);E`%"@
MX00`H.$P,`OE>?[_ZS002^(`<*#A!0"@X2[__^L`@%#B/@``"G+^_^L'`%#A
M-0``*L`QG^4T@!OE`Y"9YPB!H.$`,-7E/0!3X@$`H!,``%/C``"@`P``4.,%
M```*!0"@X0$P\.4``%/C/0!3$_O__QH%`$#@`G"'X@``A^``<)GE8?[_ZP``
M4.,(`(?G5```"@`PU>4`()GE/0!3XP``4Q,T$!OE`0"%X@$1DN<`,,'E!@``
M"@$@@>(!,-#D`A"@X3T`4^,``%,3`3#"Y/G__QH],*#C`2"@X0`PP>4!,-3D
M``!3XP$PXN7[__\:``"@XS`@&^4`,);E`P!2X3H``!HHT$OB\*^=Z`$P2.(!
M(-3D``!2XP$@X^7[__\:\O__ZM`PG^4#D)GG`""9Y0"@DN4``%KC"!"@`PD`
M``H(,*#A`A"@X0```.H*,*#A!`"QY0&@@^(``%#C^O__&@,P@^(#$:#AD#"?
MY0,PC^```)/E``!0XQ,``!H!P*#C`0"@X0#`@^4\(`OE'_[_ZP`P4.(X,`OE
M$@``"CP@&^4*@:#A`A"@X0@@H.%=_?_K.#`;Y0`PB>4`$*#C`2"*X@(1@^<T
MH`OEG?__Z@(`H.%1_?_K``!0XP`PH.$``(GE"H&@$?/__QH``.#CP/__ZHC]
M_^O\<@$`0`$``#@!``"8<P$`#<"@X3#8+>D$L$SBH-!-XG`PG^5P()_E`S"/
MX`)`D^>T$$OB`#"4Y0!0H.$8,`OE8OW_ZP``4.,``*`3!```&JPP&^4/.@/B
M"@I3XP$)4Q,%```*&"`;Y0`PE.4#`%+A!P``&A302^(PJ)WH!0"@X0(0H..T
M_?_K$`]OX:`"H.'S___J8OW_Z\QP`0!``0``#<"@X?#;+>D$L$SB0=Y-XO0P
MG^5"SDOB",!,XNP@G^4#,(_@,,0+Y0)0D^<`<*#AW`"?Y0`PE>4!D*#AU""?
MY0P0H.$``(_@*#`+Y5O]_^L`@%#B(@``VKP`G^4!0$CB``"/X,']_^LD,$OB
M!#"#X`0T4^4`8)#E``!3XQ$```H(0*#A!""@X2\0H.,P!!OEC_W_ZP``4.,,
M```*!#"@X0<0H.$&`*#A,"0;Y93]_^LH(!OE`#"5Y0,`4N$1```:)-!+XO"K
MG>@``%3C[/__&@D@H.$'$*#A!@"@X2O]_^OR___J-`"?Y0``C^"?_?_K`&"0
MY0D@H.$'$*#A!@"@X2+]_^OI___J'?W_ZS1P`0!``0``>"<``/\#```D<0$`
MG'`!``W`H.$PV"WI`=M-X@2P3.((T$WBT#"?Y=`@G^4#,(_@`E"3YT%.2^((
M0$3B`#"5Y0`0H.$!*Z#C!`"@X1@P"^73_/_K!`!`X`$`0.(`,(3@!`!3X0H`
M`)H`(-3G+P!2XP<``!H`$*#C`@``Z@`@T^4O`%+C`@``&@$00^0$`%/A^?__
M&B\0H.,$`*#AS_S_ZP``4.,*```*!`!0X0`PH(,`,,"%!`"@X4G]_^L8(!OE
M`#"5Y0,`4N$*```:%-!+XC"HG>@8(!OE`#"5Y0,`4N$$```:&`"?Y0``C^`4
MT$OB,&B=Z#K]_^K<_/_K%&\!`$`!``"P)0``#<"@X?#8+>E$()_E1`"?Y40P
MG^4$L$SB`B"/X```C^`X4)_E.$"?Y0-@DN=(_?_K!5"/X`1`C^`%,*#A!B"@
MX000H.$``)#E'-!+XO!HG>CT_/_J(&X!`$QO`0`D`0``3"4``(`E```-P*#A
M,-@MZ50`G^4(T$WB!+!,X@``C^`S_?_K`%"@X0``D.7;___K`!"@XS1`G^4T
M,)_E!$"/X`,@E.<L,)_E``"5Y000C>4D$)_E`S"/X``PC>4!$(_@\_S_ZQ30
M2^(PJ)WH[&X!`)QM`0!P`0``Z"<``!0E`````*#C'O\OX0W`H.'PWRWI$]U-
MX@2P3.(,T$WB-#*?Y30BG^4#,(_@`B"3YP!`H.$3?4OB)`*?Y0`PDN4,<$?B
M`6"@X0``C^`$$$?BX"0+Y3`P"^6\_?_K+Q"@XP!0H.$$`*#A6OS_ZP``4.,+
M```*[`&?Y000H.$``(_@;O[_ZP0`H.'@-!OE,"`;Y0`PD^4#`%+A;@``&BC0
M2^+PKYWH!@"@X=3\_^NX$9_E`1"/X'W\_^L`D%#B[/__"J@QG^6HH9_E`S"/
MX-PT"^6@,9_EH(&?Y0,PC^#D-`OEF#&?Y0J@C^`#,(_@V#0+Y0`PV>4``%/C
M/0``"@``5>,$```*"1"@X04`H.'?_/_K``!0XRT```H)`*#ATOS_ZP$00.(!
M,(G@`P!9X0!@H.$-```J`1#9YR\`4>,*```:``"@XP(``.H`(-/E+P!2XP(`
M`!H!`$/D`P!9X?G__QH)`*#AP/S_ZP!@H.$$`*#AO?S_ZP8`@.`!`(#B"`!0
MX;O__XK8-!OE0VY+X@0PC>4!*Z#C"C"@X0`0H.,(0(WE`)"-Y08`H.%8_/_K
M!Q"@X08`H.$E_/_K``!0XP,``!K$-!OE#SH#X@()4^,2```*K!"?Y0``H.,!
M$(_@,_S_ZP"04.*B__\*`##9Y0``4^/!__\:``!5XQ,```K<%!OE!0"@X:'\
M_^L``%#C`6"@$]R4&Q7M__\*T___Z@$0H.,&`*#A9OS_ZP``4./G__\:4`"?
MY080H.$``(_@__W_ZP8`H.%M_/_KCO__Z@%@H./DE!OEQ/__Z@O\_^LT;0$`
M0`$``,0D``"<)```>"0``.PC``!()```W",``/\#```()P``4",``.`B```-
MP*#A+Q"@XS#8+>D$L$SB`$"@X=7[_^L``%#C`4"`$@0`H.$4T$OB,&B=Z%#\
M_^H-P*#A,-@MZ0!`4.($L$SB"@``"@`PU.4``%/C!P``"F+\_^L!`(#B`0M0
MXP@``(H$`*#A%-!+XC!HG>C+_O_J%`"?Y0``C^`4T$OB,&B=Z#O\_^H``*#C
M,*B=Z+0A```-P*#A<-@MZ02P3.(,T$WB7#&?Y5PAG^4#,(_@`E"3YU0!G^4`
M,)7E``"/X"`P"^4Y_?_K1`&?Y41AG^4``(_@-?W_ZSP!G^4&8(_@``"/X#']
M_^LP`9_E)$!+X@``C^`M_?_K)`&?Y0``C^`J_?_K'`&?Y0``C^`G_?_K%`&?
MY0``C^`D_?_K#`&?Y0``C^`A_?_K!@"@X1_]_^O\`)_E``"/X!S]_^OT`)_E
M``"/X!G]_^OL`)_E!!"@X0``C^#;_/_K`!!0X@$```H&`*#AD_W_Z]``G^4$
M$*#A``"/X-/\_^L`$%#B`@``"KP`G^4``(_@BOW_Z[0`G^4$$*#A``"/X,K\
M_^L`$%#B#0``"J``G^4``(_@@?W_ZY@0G^68`)_E`1"/X```C^!\_?_K("`;
MY0`PE>4#`%+A"P``&AC02^)PJ)WH=`"?Y000H.$``(_@MOS_ZP`04.+N__\*
M8`"?Y0``C^!M_?_KZO__ZG[[_^LH:@$`0`$``/`A``#H(0``("(``.`A``#<
M(0``V"$``-PA``!P(0``T"$``-0A``!0(0``Q"$``+@A``"X(0``M"$``-P@
M```8(P``&"$``'0A``#X(```#<"@X1#8+>D$L$SB#-!-XEPPG^5<()_E`S"/
MX`)`D^=4`)_E`""4Y1P02^(``(_@&"`+Y8O\_^L``%#C!0``"@``T.4``%#C
M,`!0$P$`H`,``*`3`0`@XA@@&^4`,)3E`P!2X0$``!H0T$OB$*B=Z$O[_^M<
M:`$`0`$``&0@```-P*#A#P`MZ0#8+>D4L$SB"-!-XC0PG^4T$)_E`S"/X`$`
MD^<(((OB``"0Y200G^44(`OE$``+Y0$`D^<$$)OEL`"`XHW[_^O_`*#C\OK_
MZ]AG`0!``0``:`$```W`H.'PWRWI`=A-X@2P3.(DT$WB`N"@XZ01G^6DP9_E
M`1"/X`P0D><!R$OB1,!,X@`0C.4`X(WE`!"1Y0`@H.,`,*#C`("@X3`0"^6#
M^__K`4!0X@!0P>+%;Z#A!@"@X0!PH./&'Z#A!F`DX``@5N!R8/_F`"`FX`$P
M)^``(%+@`3##X`)`5.`#4,7@``!4XP`PU>($8*#A!7"@X3\``+HD,9_E`2A+
MXB!1G^4#,(_@0"!"X@%(2^(4D9_E`#""Y050C^`X0$3B`!"@XP8@H.$',*#A
M`!"-Y0@`H.%?^__K`##@XP`@X.,#`%'A`@!0`2T```H)(*#A!!"@X0@`H.$4
M^__K`0!PXQH```H'`%#C&P``F@@`0.(`H)3@`P``.A<``.H!H$KB!`!:X10`
M`#H((*#C!1"@X0H`H.$[^__K``!0X_;__QH$0$K@!`"6X,0?I^`!.$OB1#!#
MX@`PD^4P(!OE`#"3Y0,`4N$3```:*-!+XO"OG>A8`)_E``"/X(?__^L`,.#C
M`6A6X@!PQ^)$()_E`P!7X0(`5@')__\:``#@XP`0X./I___J`3A+XD`P0^(`
M`)/E>?__Z\S__^K`^O_K>&<!`$`!``"$'P``5&@!``@``0#$'@````#__PW`
MH.$`V"WI!+!,XB?[_^L@^__K``!0XP``D!4`J)WH#<"@X?#9+>D$L$SB%-!-
MXL0PG^7$()_E`S"/X`)`D^>\8)_E`#"4Y09@C^``4*#A+!!+X@8`H.$H,`OE
MTOO_ZP!P4.(%$*#A&0``"@`PU^4``%/C%@``"FKZ_^L``%#C%@``&@4`H.$.
M^__K`("@X0<`H.$+^__K``"(X`(`@.(.^__K`("@X5@PG^58$)_E`'"-Y04@
MH.$#,(_@`1"/X/?Z_^L($*#A!@"@X7+\_^L"``#J-`"?Y0``C^!N_/_K*"`;
MY0`PE.4#`%+A`0``&B#02^+PJ9WH>OK_ZX!E`0!``0``)!X``,P<``#,'```
ME!T```W`H.'PWRWI!+!,XDG?3>+XQ9_E^(6?Y0S`C^#T-9_E.`$+Y0B`C^`,
M((SB&$",XDMO2^)%[TOB`U"8YP<`DN@'`(;H#P"TZ`\`KN@#`)3H,,",XA).
M2^(#`([H!P"<Z`<`A.BP!9_E`#"5Y3Q1"^437DOB!1"@X0``C^`P,`OEA/O_
MZP!P4.("```*`##7Y0``4^.+```:D___ZP"@4.*-```*"@"@X<'Z_^N``*#A
M`0"`XL3Z_^L`(-KE`)"@X0``4N,)```*"4"@X4QUG^4'<(_@!`"@X0<0H.&K
M^O_K`2#ZY0)`A.(``%+C^/__&A0!&^4``%#C$@``"A%.2^("``#J!`"4Y```
M4.,-```*!1"@X5_[_^L`<%#B^/__"@`PU^4``%/C]?__"J/\_^L``%#C\O__
M"@<`H.&!^O_K`*!0XA<``!H`<*#C+#!+X@<Q@^``01/E``!4XPH```H`,-3E
M``!3XP<```H$`*#ADOS_ZP``4.,!<(?B!```&@=!EN<``%3C]/__&@"@H.,$
M``#J!`"@X6KZ_^L``%#CZ?__"@"@H.$*`*#A@/K_ZP!@H.$)`*#A??K_ZP``
MAN`!:X#B!&"&X@8`H.%^^O_K`$"@X4@TG^5(%)_E`S"/X``PC>5`-)_E"B"@
MX0,PC^`!$(_@!)"-Y63Z_^L$`*#A!QV@XS3Z_^L!`'#C&@``"OP02^($`*#A
MV/G_ZP!P4.(#```:]#`;Y0\Z`^(!"5/C00``"O0CG^7T$Y_E`@"8YS@A&^4$
M,*#A`""2Y;``@.(!$(_@U?G_ZP!@H.,\,1OE,"`;Y0`PD^4&`*#A`P!2X>4`
M`!HHT$OB\*^=Z`WZ_^L`,)#E$0!3X^#__PHX,1OE`&"@XP!0D^4&^O_KC#.?
MY0`0D.4#`)CG`!"-Y803G^4%(*#A!#"@X;``@.(!$(_@NOG_Z^3__^H/___K
M!P"@X1SZ_^L`8*#AW___Z@IPH.$'`93G``!0XPP```H%$*#AZ/K_ZP`P4.(!
M<(?B]___"@`PT^4``%/C]/__"@WZ_^L``%#C\?__"@"@H.%@___J#0"@XRCZ
M_^L,HY_E`)"@X0J@C^!3(*#C8O__ZN"0&^45^O_K``!9X;G__QKT,!OE@SN@
MX:,[H.$'#5/CM/__&@8`H.$8^O_K`&"@X<P"G^4%$*#A``"/X,;Z_^L`$%#B
M4```"C@Q&^4``)/E\/S_ZP!04.)+```*!0"@X03Z_^L#`%#C`("@X0P``)J0
M$I_E!`!`X@``A>`!$(_@!?K_ZP``4.,%```:!`!8XWX```H(@(7@!3!8Y2\`
M4^-Z```*$O[_ZP"@4.($```:!0"@X0H0H.'?^?_K`%!0XC0``!I`$I_E0`*?
MY0$0C^```(_@7/O_Z[_Y_^LP,I_E,!*?Y0,PC^`)`(WH*#*?Y2B2G^4H@I_E
M*%*?Y0,PC^`$(*#A`1"/X`8`H.'0^?_K"9"/X`B`C^`%4(_@#```ZI7Y_^L`
M,)#E$0!3XPT``!JI^?_K`7"'XH$`C>@(4(WE"3"@X00@H.$($*#A!@"@X;_Y
M_^L'':#C!@"@X8_Y_^L!`'#C[?__"@0`H.$H^?_KM`&?Y080H.$``(_@,OO_
MZP8`H.&1_O_K9/__ZC@Q&^4`4)/EL/__Z@S^_^L``%#C`##1X@"`H.$!D*#A
MQ/__N@H@4.(`,,'B`*"-Y04`H.%DH$OBF?G_ZPH0H.$&(*#C!0"@X5/Y_^L&
M`%#C`@``"D@!G^4``(_@X?W_ZT`QG^5D$!OE`S"/X`P@D^4,,(/B`@!1X:[_
M_QJT(-KAM##3X0,`4N&J__\:`!"@XS(@6.(`,,GB`!"-Y04`H.%<<$OB?OG_
MZP4`H.$'$*#A*""@XSCY_^LH`%#C`@``"N0`G^4``(_@QOW_ZP#`H./8,)_E
MV!"?Y0,PC^`$,(WET#"?Y0!PC>4#,(_@!""@X0$0C^`&`*#A-,!+Y7'Y_^NU
M___J.#$;Y02`D^4``%CC@/__"@@`H.%S^?_K`P!0XWS__YJ0$)_E!`!`X@``
MB.`!$(_@=?G_ZP``4.,(4*`!=/__ZO#X_^L(9@$`@&0!`$`!``#<&P``H!P`
M`*@;``"(&P``3!T``&@!``!X&P``T!H``#@:``"H&@``;!H``)@:``"T&```
MZ!H``!`:````&P``[!H``!`:``"T&@``H!<``!09``"X%@``J!@``&@9``"(
M&```B!D``#08```-P*#A\-DMZ02P3.(,T$WB+#*?Y2PBG^4#,(_@`E"3YR0"
MG^4`()7E``"/X"@@"^5`^?_K`#"0Y1`"G^5D(-/E+&!+X@80H.$``(_@92##
MY>[Y_^L``%#C`@``"@`PT.4Q`%/C7@``"MO\_^O@`9_EX$&?Y0``C^`N^?_K
M!$"/X`00H.$`<*#A`S"@XP``D.4!(*#CROC_ZP!`4.(*```*##"4Y;`AG^4`
M$)/E`B"/X```E^6G^/_K##"4Y0`0D^4(,)'E`043XU$``!J,`9_EC$&?Y0``
MC^`6^?_K!$"/X`00H.$`<*#A`S"@XP``D.4!(*#CLOC_ZP!`4.()```*8`&?
MY080H.$``(_@O_G_ZP`@4.(V```*##"4Y0``E^4`$)/EB_C_ZSP!G^4\@9_E
M``"/X/_X_^LT$9_E`'"0Y0!`H.$!(*#C`1"/X`<`H.&G^/_K'"&?Y0`0H.$"
M((_@!P"@X7OX_^L`(*#C`#"4Y00!G^4&$*#A92##Y0``C^"B^?_K"("/X```
M4.,(`(CE"P``"@<=H..M^/_K`3"`XA$`4.,!`%,3'0``BB@@&^4`,)7E`P!2
MX1@``!H@T$OB\*F=Z`0`F.7J_?_K``!0XP@`B.7N__\:H`"?Y0``C^"&^/_K
M`3#0Y0``4^.>__\*G/__ZH@PG^4,()3E`S"/X`0PD^4``)+E`!"3Y>WZ_^O$
M___J``"7Y8KX_^NJ___J2?C_ZUP@G^4`,*#A6`"?Y0(@C^`&`)+I``"/X``0
MD>5N^/_K!%X!`$`!```D7P$`U!4``-A>`0!P%P``1!<``'A>`0`<%P``T!0`
M`!Q>`0"T7@$`M!8``+@6``!0%```0!8``#Q>`0`(7@$`"!8```W`H.$PV"WI
M!+!,X@!`H.'`_/_K``!0XP``5!,PJ)T(`##4Y0``4^,PJ)T(!`"@X2W\_^L@
M_/_K(!"?Y00@H.,!$(_@\O?_ZP``4.,PJ)T8!`"@X1302^(P:)WHJ_G_ZBP4
M```-P*#A\-\MZ02P3.)5WTWBT#N?Y=#KG^4#,(_@#N"3YUW/2^(.0*#A#!"@
MX0!`E.5XX0OE'""`XES@@.(P0`OE!#"2Y#,_O^8"`%[A!#"AY?K__QITX$OB
M.#"<Y21`G.4,$)SE!#`CX`0@O.4!,"/@`C`CX.,_H.$.`%SA0#",Y?3__QH$
M$)#E8#N?Y0C`D.5P(1OE`$"0Y6%AH.$0@)#E;!$;Y0S@D.4&4"S@`R""X`@@
M@N`$4`7@!("0Y0,0@>`.<"S@#%`EX`X0@>`!D(7@"'`'X&@1&^5D@:#A#G`G
MX.0M@N`'((+@9*$;Y0-P@>`($";@8E&@X0(0`>`,<(?@XBV)X`.@BN`%D"C@
M!A`AX`<0@>`&8(K@8G&@X0*0">!@H1OEXBV!X`B0*>`'$"7@!I")X`.@BN`"
M$`'@8F&@X>*=B>`(H(K@!2`AX%P1&^4&@"?@"B""X.DM@N`#H('@"8`(X&D1
MH.%8D1OE!X`HX`6@BN`!4";@"J"(X`.0B>`"@`7@!Y")X`:`*.!B4:#AXBV*
MX`F@B.!4@1OE!7`AX`.0B.`"@`?@!I")X`&`*.!B<:#AXBV*X`F@B.!0@1OE
M!V`EX`.0B.`"@`;@`9")X`6`*.!B8:#AXBV*X`F@B.!,@1OE!A`GX`.0B.`"
M@`'@!9")X`>`*.!B$:#AXBV*X`F@B.!(@1OE`5`FX`.0B.`"@`7@!Y")X`:`
M*.!B4:#AXBV*X`F@B.!$@1OE!7`AX`.0B.`"<`?@!I")X`%P)^!B@:#AXBV*
MX`F@A^!`<1OE"&`EX`.0A^`"<`;@8F&@X05P)^#B+8K@`1")X#RA&^4&D"C@
M`1"'X`*0">!B<:#A`Z"*X.(M@>`($"G@.)$;Y06@BN`'4";@"A"!X`.@B>`"
MD`7@"("*X`:@*>!B4:#A"*"*X#2!&^7B'8'@!2`GX`.0B.`!(`+@88&@X>&M
MBN`&8(G@!Q`BX`80@>`P81OE""`EX`.0AN#J'8'@:F&@X0H@`N`LH1OE!W")
MX`4@(N`&D"C@!R""X`&0">`#<(K@**$;Y>$M@N`%4(?@81&@X0B0*>`#H(K@
M!9")X`%0)N!B<:#AXIV)X`)0!>`(((K@)*$;Y0>`(>`&4"7@"8`(X`)0A>`#
M,(K@E"B?Y2"A&^4&,(/@`6`HX&F!H.'IG87@`U"&X`)@BN`(,"?@'*$;Y0$0
MAN`)8"/@:3&@X>E=A>`&8('@&)$;Y0(0BN`#H"C@!:`JX`<0@>!E<:#AY6V&
MX`H0@>`"4(G@%*$;Y0>0(^`&D"G@"%"%X&:!H.'F'8'@"5"%X`*@BN`(D"?@
MX6V%X`,PBN`!4"G@!5"#X!`Q&^5A$:#A#)$;Y0*@@^`!,"C@!Z"*X`8P(^!F
M<:#AYEV%X`,PBN`"8(G@"*$;Y0>0(>`%D"G@"&"&X&6!H.'E/8/@"6"&X`A0
M)^`"D(K@!*$;Y>-MAN`!$(G@`U`EX&,QH.$`D1OE!5"!X`*@BN`#$"C@!Z"*
MX`80(>!F<:#AYEV%X`$0BN`"8(G@_*`;Y0>0(^`%D"G@"&"&X&6!H.'E'8'@
M"6"&X`A0)^`"D(K@^*`;Y>%MAN`#,(G@`5`EX&$1H.'TD!OE!5"#X`*@BN`!
M,"C@!Z"*X`8P(^!F<:#AYEV%X`,PBN`"8(G@\*`;Y0>0(>`%D"G@"&"&X&6!
MH.'E/8/@"6"&X`A0)^`"D(K@[*`;Y>-MAN`!$(G@`U`EX&,QH.'HD!OE!5"!
MX`*@BN`#$"C@!Z"*X`80(>!F<:#AYEV%X`$0BN`"8(G@Y*`;Y0>0(^`(8(;@
M!8`IX&61H.'E'8'@"("&X`)@BN`)H"?@`S"&X`%@*N`&8(/@X#`;Y>%=B.!A
M$:#AW(`;Y0*@@^`!,"G@!Z"*X`4P(^!E<:#AY6V&X`,PBN`"4(C@V*`;Y0>`
M(>`)4(7@!H`HX&:1H.$"H(K@YFV#X`B`A>`),"?@U%`;Y>:-B.`!$(K@!C`C
MX&9AH.$"H(7@`S"!X`80*>!H4:#AZ"V#X`=PBN`!@"C@!#:?Y0B@A^#0<!OE
M!1"&X0.`A^`"$`'@8G&@X>(MBN`%H`;@"9"(X`J@@>',$!OE!X"%X0F@BN`"
M@`C@`Y"!X&(1H.'B+8K@!Z`%X`9@B>`*H(CAR)`;Y0&`A^$&H(K@`Y")X&)A
MH.$"@`C@XBV*X`&@!^`%4(G@"J"(X<20&^4&@('A!:"*X`.0B>!B4:#A`H`(
MX.(MBN`&H`'@!W")X`J@B.'`D!OE!8"&X0>@BN`#D(G@8G&@X0*`".#B+8K@
M!:`&X`$0B>`*H(CAO)`;Y0>`A>$!H(K@`Y")X&(1H.$"@`C@XBV*X`>@!>`&
M8(G@"J"(X;B0&^4!@(?A!J"*X`.0B>!B8:#A`H`(X.(MBN`!H`?@!5")X`J@
MB.&TD!OE!H"!X06@BN`#D(G@8E&@X0*`".#B+8K@!J`!X`=PB>`*H(CAL)`;
MY06`AN$'H(K@`Y")X&)QH.$"@`C@XBV*X`6@!N`!$(G@"J"(X:R0&^4'@(7A
M`:"*X`.0B>!B$:#A`H`(X.(MBN`'H`7@!F")X`J@B.&HD!OE`8"'X0:@BN`#
MD(G@8F&@X0*`".#B+8K@`:`'X`50B>`*H(CAI)`;Y0:`@>$%H(K@`Y")X&)1
MH.$"@`C@XBV*X`:@`>`'<(G@"J"(X:"0&^4%@(;A!Z"*X`.0B>!B<:#A`H`(
MX.(MBN`%H`;@`1")X`J@B.&<D!OE!X"%X0&@BN`#D(G@8A&@X0*`".#B+8K@
M!Z`%X`9@B>`*H(CAF)`;Y0&`A^$&H(K@`Y")X&)AH.$"@`C@XBV*X`&@!^`%
M4(G@"J"(X920&^4&@('A!:"*X`.0B>!B4:#A`H`(X.(MBN`&H`'@!W")X`J@
MB.&0D!OE!8"&X0>@BN`#D(G@8G&@X0*`".#B+8K@!:`&X`$0B>`*H(CAC)`;
MY0>`A>$!H(K@`Y")X&(1H.$"@`C@XBV*X`>@!>`&8(G@"J"(X8B0&^4!@(?A
M!J"*X`.0B>!B8:#A`H`(X.(MBN`!H`?@!9")X`J`B.$)@(C@A)`;Y090@>$#
M,(G@!W"#X`:0`>#T,I_E`E`%X("@&^7BC8C@"5"%X6(AH.%\D!OE!U"%X`-P
MBN`"H";@"*`JX`$0A^!H<:#AZ%V%X`H0@>`#@(G@>*`;Y0>0(N`%D"G@!H"(
MX&5AH.'E'8'@"8"(X`90)^`#D(K@=*`;Y>&-B.`"((G@`5`EX&$1H.%PD!OE
M!5""X`.@BN`!(";@!Z"*X`@@(N!H<:#AZ%V%X`(@BN`#@(G@;*`;Y0>0(>`%
MD"G@!F"(X&6!H.'E+8+@"6"&X`A0)^`#D(K@:*`;Y>)MAN`!$(G@`E`EX&(A
MH.%DD!OE!5"!X`.@BN`"$"C@!Z"*X`80(>!F<:#AYEV%X`$0BN`#8(G@8*`;
MY0>0(N`%D"G@"&"&X&6!H.'E'8'@"6"&X`A0)^`#D(K@7*`;Y>%MAN`"((G@
M`5`EX&$1H.%8D!OE!5""X`.@BN`!("C@!Z"*X`8@(N!F<:#AYEV%X`(@BN`#
M8(G@5*`;Y0>0(>`%D"G@"&"&X&6!H.'E+8+@"6"&X`A0)^`#D(K@4*`;Y>)M
MAN`!$(G@`E`EX&(AH.%,D!OE!5"!X`.@BN`"$"C@!Z"*X`80(>!F<:#AYEV%
MX`$0BN`#8(G@2*`;Y0>0(N`(8(;@!8`IX&61H.'E'8'@"("&X`-@BN`)H"?@
M`B"&X`%@*N`&8(+@1"`;Y>%=B.!A$:#A`Z""X$"`&^4!("G@!Z"*X`4@(N!E
M<:#AY6V&X`(@BN`#4(C@/*`;Y0>`(>`&@"C@"5"%X&:1H.'F+8+@"%"%X`.@
MBN`)@"?@XFV%X`%0BN`"$"C@-*`;Y0$0A>`X4!OE8B&@X0.`A>`#,(K@`E`I
MX&:AH.'F'8'@!W"(X`0P@^`*@"+@!E`EX`&`*.`),(/@!5"'X.%=A>`(@(/@
MY3V(X&$1C.!X01OE$,"0Y0`P@.4"((S@,#`;Y03`D.4`0)3E!5",X`K@CN`$
M`%/A"!"`Y1`@@.4$4(#E#."`Y0$``!HHT$OB\*^=Z!OU_^L06P$`0`$``)EY
M@EJAZ]ENW+P;C];!8LH-P*#A8`"@XS#8+>D$L$SBCO7_ZP`@H.,L$)_E+$"?
MY2S@G^4LP)_E`!"`Y2@0G^400(#I#,"`Y1`0@.44((#E&""`Y5P@@.4PJ)WH
M`2-%9XFKS>_^W+J8=E0R$/#ATL,-P*#A\-LMZ10PD.4"@*#A@B&@X0(PD^``
M(*#C`2"@(P!@H.$``%+C&""0Y5P`D.4!(((2J"Z"X```4.,$L$SB`4"@X1@@
MAN44,(;E')"&X@X```I`4&#B!0!8X0A0H+$``(G@!2"@X=ST_^M<,);E`S"%
MX$``4^-<,(;E\*N=&`8`H.$%@$C@!4"$X,/\_^L_`%CC&0``VD"`2.(H4Z#A
M`7"%X@=SA.`$$*#A"3"@X4`@A.(`0)'E!."1Y0C`D>4,`)'E$!"!X@(`4>$`
M0(/E!."#Y0C`@^4,`(/E$#"#XO/__QH!0*#A!@"@X:O\_^L'`%3AZ___&@5=
M9>`%@XC@!!"@X0D`H.$((*#AL_3_ZUR`AN7PJYWH#<"@X?#;+>D!0*#A?Q#@
MXQ1@E.4<@(3BIC&@X3\P`^(!((/B.`!2XP!0H.$8<)3E!+!,X@,0R.<"`(C@
M20``VD`@8N(`$*#CO/3_ZP0`H.&,_/_K"`"@X3@@H.,`$*#CMO3_ZR<\H.$F
M+*#A)PB@X2<4H.%;8,3E5##$Y28XH.$F9*#A50#$Y5DPQ.4$`*#A5W#$Y580
MQ.58(,3E6F#$Y7C\_^L#,-3E!`"@X0`PQ>6R,-3A`3#%Y0`PE.4C-*#A`C#%
MY0`PE.4#,,7E!S#4Y00PQ>6V,-3A!3#%Y00PE.4C-*#A!C#%Y00PE.4',,7E
M"S#4Y0@PQ>6Z,-3A"3#%Y0@PE.4C-*#A"C#%Y0@PE.4+,,7E#S#4Y0PPQ>6^
M,-3A#3#%Y0PPE.4C-*#A#C#%Y0PPE.4/,,7E$S#4Y1`PQ>6R,=3A$3#%Y1`P
ME.4C-*#A$C#%Y1`PE.43,,7E)-!+XO!KG>@\]/_J."!BX@`0H.-R]/_KNO__
MZ@W`H.$PV"WI8#"?Y6!`G^4#,(_@)"#3Y01`C^```%+C!+!,XC"HG1@!$*#C
M1""?Y200P^4",)3G``!3XP(```HT,)_E`P"?YPWT_^LL,)_E`S"4YP``4^,P
MJ)T((`"?Y0``C^`4T$OB,&B=Z'GT_^H<3@$`($P!`!P!``!L30$`5`$``'!%
M```\$)_E/#"?Y0$0C^``(-'E`S"/X```4N,>_R\1`0"@XR0@G^4``,'E`C"3
MYP``4^,>_R\!%`"?Y000@>(``(_@:_3_ZIQ-`0"@2P$`6`$```Q%```-P*#A
M\-@MZ02P3.(@T$WB+%*?Y2PRG^4%4(_@*``+Y2P0"^4P(`OE`T"5YS`@2^(`
M,)3E+!!+XB@`2^(@,`OE./3_ZP`BG^4`,I_E`B"5YP,`E><"$*#A/O3_Z_`Q
MG^4#,)7G`&#3Y0``5N-/```*X`&?Y0``C^!^]/_K`""0Y2A@&^5&,]+E!`"&
MX@,P@^,'`7#C1C/"Y0-@AN)8``"*``&@X1/T_^L`P*#A+#`;Y:0AG^6D$9_E
M``"3Y0(@C^`$P(+E`1"/X)0AG^4``(SE!!",Y0(0E><H(!OE``"1Y8`1G^4!
M`%+C`1"/X/@`S.$0$*#3"```V@3@0^("X8[@#!",X@0`L^4.`%/A!`"AY?O_
M_QH#((+B`A&@X0#@H.-$49_E`>",YT`1G^4%4(_@#`"5Y08@H.$`X(WE##"@
MX0$0C^`8]/_K``!0XRD```H<49_E)&!+X@50C^`,`)7EQO/_ZP!PH.$(`9_E
M!A"@X0``C^#U]/_K``!0XQ@```KT,)_E`S"/X`P`D^6L\__K\_/_ZR`@&^4`
M,)3E!P"@X0,`4N$C```:'-!+XO"HG>B[\__KQ#"?Y0``4.,#,(_@#`"#Y1P`
M``J1\__KL`"?Y0``C^`G]/_K`#"0Y>9EP^6B___J"`"5Y0``4.,)```*=OO_
MZ^'__^H,`)7E!?3_Z]+__^I\,)_E?`"?Y0,0E><``(_@R?/_ZW``G^4&$*#A
M``"/X,GT_^L``%#C"`"%Y=+__PKM___JD_/_ZP$`H.-/\__K1$L!`$`!``!0
M`0``8`$``"P!```83`$`O$P!```%``!,`0``X`0``$Q,`0!$W/__($P!`/P!
M``#T2P$`O$L!`+Q*`0!(`0``]`(``.P```!P<U]S=')I;F=S(&UI<W-I;F<*
M`'!E<FQX<VDN8P````!#04-(10``+@```"XN```E<R\E<P```"]P<F]C+V-U
M<G!R;V,O97AE````1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`````%!!4E]414U0`````%!!4E]04D]'3D%-10``
M```Z````)7,E<R5S``!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4````
M`%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!
M3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'3$]"04Q?1$5"54<`
M````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2``!005)?1TQ/0D%,
M7U1%35``4$%27T=,3T)!3%]#3$5!3@````!L<V5E:R!F86EL960`````<F5A
M9"!F86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S
M)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD
M(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R
M`````'-H;W)T(')E860``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S
M````)7,E<W1E;7`M)74M)74E<P`````8````<&5R;``````P````4$%2.CI0
M86-K97(Z.E9%4E-)3TX`````,2XP-C$```!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H
M92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M
M+0``55-%4@````!54T523D%-10````!414U01$E2`%1-4``O=&UP+P```&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C
M:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A
M8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P
M-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H
M=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@
M)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O
M<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"10
M05)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU
M;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R
M:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@
M)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^
M)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R
M7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S
M*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O
M;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@
M34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I
M.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA
M9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I
M=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?
M1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#
M04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@
M;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M
M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O
M9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO
M=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D
M;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@[
M"FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN
M72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@
M=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D
M9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T
M<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D
M<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@
M<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*
M:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A
M<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q
M("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V
M:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D
M,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I
M('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I
M('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]
M("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL
M)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@
M*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q
M6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E
M<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF
M("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%2
M7U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E
M9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D
M:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM
M>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N
M;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC
M;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB
M:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F
M:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A
M9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B
M.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C
M:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@
M;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF
M("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME
M>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92![
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D
M:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*
M;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@
M>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN
M9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D
M=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B
M/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF
M("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*
M?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@
M/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^
M861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D
M8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<
M,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F
M9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E
M(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D
M(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]
M($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F
M86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(
M*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@
M*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP
M+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@
M>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;
M17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER
M(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K
M("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H
M*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG
M=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D
M8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H
M95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D
M8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%2
M7T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H
M95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*
M;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@
M)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM
M>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I
M;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O
M9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6
M>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH``1L#.P@!```@````3(___R`!``"LC___
M1`$``#20__]L`0``Y)'__]0!``#,DO__``(``'23__\P`@``U)3__V0"```,
ME___G`(``)R7___(`@``P)C___P"``"XF?__.`,``"":__]P`P``F)K__Y@#
M``"@FO__K`,``""=___D`P``4)W__Q0$``"PG?__6`0``'R?__^(!```_)__
M_[`$``!8H/__V`0``#BB__\0!0``6*+__S`%``!,H___9`4``-2I__^<!0``
M9*S__]`%``#(K/__,`8``,BX__]H!@``*+G__XP&``!`NO__N`8``+B[__^D
M`0``0+S__Y`!``"4O/__``8``!```````````7I2``)\#@$;#`T`(````!@`
M```DCO__8`````!"#0Q(A`:%!8L$C0..`DH,"P0`)````#P```!@CO__B```
M``!"#0Q*A`B%!X8&AP6+!(T#C@)&#`L$`"````!D````P([__[`!````0@T,
M1(<%BP2-`XX"0@P+!````!````"(````J+K__U0`````````+````)P````,
MNO__B`````!"#0Q$A`:%!8L$C0..`DP,"P1B#`T80L[-R\7$#@0`*````,P`
M```(D/__Z`````!"#0Q$A`J%"88(AP>(!HD%BP2-`XX"1`P+!``L````^```
M`,20__^H`````$(-#$*$"(4'A@:'!8L$C0..`D(,"P0"1`H,#2!""P`P````
M*`$``#R1__]@`0```$(-#$*$"X4*A@F'"(@'B0:*!8L$C0..`D(,"P1B"@P-
M+$(+-````%P!``!HDO__.`(```!"#0Q"A`N%"H8)APB(!XD&B@6+!(T#C@)"
M#`L$`I@*#`TL0@L````H````E`$``&B4__^0`````$(-#$*$!H4%BP2-`XX"
M0@P+!&X*#`T80@L``#````#``0``S)3__R0!````0@T,0H0*A0F&"(<'B`:)
M!8L$C0..`D(,"P0"7`H,#2A""P`X````]`$``+R5___X`````$(-#$*$!H4%
MBP2-`XX"1`P+!`)8"@P-&$(+3@H,#1A"SLW+Q<0.!$(+```T````,`(``'B6
M__]H`````$(-#$B$"(4'A@:'!8L$C0..`D(,"P1:#`T@0L[-R\?&Q<0.!```
M`"0```!H`@``J);__W@`````0@T,1(0&A06+!(T#C@)$#`L$9@P-&``0````
MD`(``/B6__\(`````````#0```"D`@``[);__X`"````0@T,0H0+A0J&"8<(
MB`>)!HH%BP2-`XX"1`P+!`)""@P-+$(+````+````-P"```TF?__,`````!"
M#0Q$A`:%!8L$C0..`D(,"P1,#`T80L[-R\7$#@0`0`````P#```TF?__8```
M``!"#0Q"A`:%!8L$C0..`D0,"P14"@P-&$+.S<O%Q`X$0@M&"@P-&$+.S<O%
MQ`X$0@L````L````4`,``%"9___,`0```$(-#$*$!X4&A@6+!(T#C@)"#`L$
M`IP*#`T<0@L````D````@`,``.R:__^``````$(-#$*$!8L$C0..`D(,"P1P
M"@P-%$(+)````*@#``!$F___7`````!"#0Q$@`2!`X("@P&+"(T'C@9"#`L4
M`#0```#0`P``>)O__^`!````0@T,0H0+A0J&"8<(B`>)!HH%BP2-`XX"1`P+
M!`*R"@P-+$(+````'`````@$```@G?__(`````!"#0Q"BP2-`XX"0@P+!``P
M````*`0``""=___T`````$(-#$*$"84(A@>'!H@%BP2-`XX"0@P+!`)D"@P-
M)$(+````-````%P$``#@G?__B`8```!"#0Q"A`N%"H8)APB(!XD&B@6+!(T#
MC@)"#`L$`S8!"@P-+$(+```P````E`0``#"D__^0`@```$(-#$*$"84(A@>'
M!H@%BP2-`XX"0@P+!`+:"@P-)$(+````+````,@$``",IO__9`````!"#0Q"
MA`:%!8L$C0..`D(,"P1F#`T80L[-R\7$#@0`+````/@$``",MO__E`(```!"
M#0Q"A`B%!X8&AP6+!(T#C@)"#`L$`M`*#`T@0@L`-````"@%``"0IO__``P`
M``!"#0Q"A`N%"H8)APB(!XD&B@6+!(T#C@)"#`L$`^H%"@P-+$(+```@````
M8`4``%BR__]@`````$(-#$2$!H4%BP2-`XX"0@P+!``H````A`4``)2R__\8
M`0```$(-#$2$"H4)A@B'!X@&B06+!(T#C@):#`L$`#P```"P!0``@+/__W@!
M````0@T,0H0*A0F&"(<'B`:)!8L$C0..`E8,"P0"E@H,#2A"SLW+R<C'QL7$
M#@1""P``````W$,``%1#`````````0````$````!````RP(```$```#5`@``
M`0```.,"```!````"0,```\```"B!```&0```)B.`0`;````!````!H```"<
MC@$`'`````0````$````>`$```4```!T"P``!@```+0$```*````ZP0```L`
M```0````%0`````````#````E(\!``(````8`@``%````!$````7````B!$`
M`!$```!@$```$@```"@!```3````"````/O__V\````(^O__;QD`````````
M````````````````````````````````````````````````I(X!````````
M````H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3
M``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,`
M`*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``
MH!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@
M$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3
M``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,`
M`*".`0``````>!$```````"8C@$`````````````````P)$!`'@1````````
MG(X!``````!,D0$`````````````````I(X!``````"$D0$```````B1`0!P
M,0``@)$!``R1`0`*4$%2+G!M"@`````D2@``[$8```````#\1P```$@``!A*
M``!(1P``($H````````$2@``#$H````````L2@``1T-#.B`H3F5T0E-$(&YB
M-"`R,#(P,#@Q,"D@-RXU+C``1T-#.B`H;F(T(#(P,C`P.#$P*2`W+C4N,``D
M3F5T0E-$.B!C<G0P+E,L=B`Q+C0@,C`Q."\Q,2\R-B`Q-SHS-SHT-"!J;V5R
M9R!%>'`@)``D3F5T0E-$.B!C<G0P+6-O;6UO;BYC+'8@,2XR,R`R,#$X+S$R
M+S(X(#(P.C$R.C,U(&-H<FES=&]S($5X<"`D`"1.971"4T0Z(&-R=&DN4RQV
M(#$N,2`R,#$R+S`X+S$S(#`R.C0Y.C`T(&UA='0@17AP("0`)$YE=$)31#H@
M8W)T8F5G:6XN8RQV(#$N,3<@,C`Q."\Q,B\R."`Q.#HQ-SHQ,2!C:')I<W1O
M<R!%>'`@)``D3F5T0E-$.B!C<G1E;F0N4RQV(#$N,B`R,#$S+S$R+S(P(#$U
M.C,U.C0X(&IO97)G($5X<"`D`````/'/`@`````````````````(````"```
M``@````(````&P````$``````````"HJ*B!.;R!,86)E;"!0<F]V:61E9"`J
M*BH``/'/`@`````````````````(````"`````@````(````&P````$`````
M`````"HJ*B!.;R!,86)E;"!0<F]V:61E9"`J*BH`03<```!A96%B:0`!+0``
M``5!4DTQ,3<V2EI&+5,`!@<(`0D!"@(2!!0!%0$7`Q@!&@(<`2(!1`$`+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N;F5T8G-D+FED96YT`"YN;W1E+FYE=&)S
M9"YP87@`+FYO=&4N;F5T8G-D+FUA<F-H`"YH87-H`"YD>6YS>6T`+F1Y;G-T
M<@`N<F5L+F1Y;@`N<F5L+G!L=``N=&5X=``N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y
M;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y354Y77V-T9@`N05)-
M+F%T=')I8G5T97,`````````````````````````````````````````````
M``````````L````!`````@```!0!```4`0``%P```````````````0``````
M```3````!P````(````L`0``+`$``!@```````````````0`````````)@``
M``<````"````1`$``$0!```4```````````````$`````````#<````'````
M`@```%@!``!8`0``(```````````````!`````````!*````!0````(```!X
M`0``>`$``#P#```&``````````0````$````4`````L````"````M`0``+0$
M``#`!@``!P````,````$````$````%@````#`````@```'0+``!T"P``ZP0`
M`````````````0````````!@````"0````(```!@$```8!```"@!```&````
M``````0````(````:0````D```!"````B!$``(@1```8`@``!@```!,````$
M````"````&T````!````!@```*`3``"@$P``.`,`````````````!`````0`
M``!R`````0````8```#8%@``V!8``.PO``````````````0`````````>```
M``$````"````Q$8``,1&``#80``````````````$`````````(`````!````
M`@```)R'``"<AP``#`$`````````````!`````````".`````0````(```"H
MB```J(@``/`%``````````````0`````````F`````X````#````F(X!`)B.
M```$```````````````$````!````*0````/`````P```)R.`0"<C@``!```
M````````````!`````0```"P`````0````,```"@C@$`H(X```0`````````
M``````0`````````M0````8````#````I(X!`*2.``#P````!P`````````$
M````"````+X````!`````P```)2/`0"4CP``=`$`````````````!`````0`
M``##`````0````,````(D0$`")$``$@```````````````0`````````R0``
M``@````#````@)$!`%"1``!$``````````````!``````````,X````!````
M,`````````!0D0``.P```````````````0````$````?`````0``````````
M````BY$``"(!``````````````$`````````UP````$``````````````+"2
M``"/```````````````$`````````.$````#``!P```````````_DP``.```
M`````````````0`````````!`````P``````````````=Y,``/$`````````
,``````$`````````
